Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Tests harness.Tests
Functions ¶
Types ¶
type GlobalOptions ¶
type GlobalOptions struct {
CloudPlatform string // only GCE is supported currently
PlatformOptions platform.Options
GCEOptions gcloud.Options
Parallel int
OutputDir string
BootkubeBinary string
BootkubeScriptDir string
}
GlobalOptions are set in main and represent options that affect all tests run in a single invocation of pluton.
var Opts GlobalOptions
Glue variable for setting global options
Click to show internal directories.
Click to hide internal directories.